==> jc-1.4.0.tar.gz: gnu/java/rmi/server/RMIHashes.h <==
// public class gnu.java.rmi.server.RMIHashes

// class file dependencies
// @dep_class 857e3dcd87e13f83 gnu_java_rmi_server_RMIHashes
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_rmi_server_RMIHashes_H_
#define _JC_gnu_java_rmi_server_RMIHashes_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_reflect_Method$object;

// Typedefs
typedef struct _jc_gnu_java_rmi_server_RMIHashes$sub_refs	_jc_gnu_java_rmi_server_RMIHashes$sub_refs;
typedef struct _jc_gnu_java_rmi_server_RMIHashes$sub_nonrefs	_jc_gnu_java_rmi_server_RMIHashes$sub_nonrefs;
typedef struct _jc_gnu_java_rmi_server_RMIHashes$refs	_jc_gnu_java_rmi_server_RMIHashes$refs;
typedef struct _jc_gnu_java_rmi_server_RMIHashes$nonrefs	_jc_gnu_java_rmi_server_RMIHashes$nonrefs;
typedef struct _jc_gnu_java_rmi_server_RMIHashes$object	_jc_gnu_java_rmi_server_RMIHashes$object;

typedef const struct _jc_gnu_java_rmi_server_RMIHashes$vmethods	_jc_gnu_java_rmi_server_RMIHashes$vmethods;
typedef const struct _jc_gnu_java_rmi_server_RMIHashes$vtable	_jc_gnu_java_rmi_server_RMIHashes$vtable;
typedef const struct _jc_gnu_java_rmi_server_RMIHashes$vtype	_jc_gnu_java_rmi_server_RMIHashes$vtype;

// Constructors
extern void _jc_gnu_java_rmi_server_RMIHashes$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_rmi_server_RMIHashes$object *);

// Static methods
extern jlong _jc_gnu_java_rmi_server_RMIHashes$method$getInterfaceHash$f12cb538871a5af9(_jc_env *, struct _jc_java_lang_Class$object *);
extern jlong _jc_gnu_java_rmi_server_RMIHashes$method$getMethodHash$a47f54d288819e0e(_jc_env *, struct _jc_java_lang_reflect_Method$object *);

// Virtual methods structure
struct _jc_gnu_java_rmi_server_RMIHashes$vmethods {
};

// Vtable
struct _jc_gnu_java_rmi_server_RMIHashes$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_rmi_server_RMIHashes$vmethods	gnu_java_rmi_server_RMIHashes;
};

// Vtype
struct _jc_gnu_java_rmi_server_RMIHashes$vtype {
	_jc_type			type;
	_jc_gnu_java_rmi_server_RMIHashes$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_rmi_server_RMIHashes$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_rmi_server_RMIHashes$refs {
    _jc_gnu_java_rmi_server_RMIHashes$sub_refs	gnu_java_rmi_server_RMIHashes;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_rmi_server_RMIHashes$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_rmi_server_RMIHashes$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_rmi_server_RMIHashes$sub_nonrefs	gnu_java_rmi_server_RMIHashes;
};

// Object instance structure
struct _jc_gnu_java_rmi_server_RMIHashes$object {
	_jc_gnu_java_rmi_server_RMIHashes$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_rmi_server_RMIHashes$vtype	*vtype;
	_jc_gnu_java_rmi_server_RMIHashes$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_rmi_server_RMIHashes$vtype _jc_gnu_java_rmi_server_RMIHashes$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_rmi_server_RMIHashes, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_rmi_server_RMIHashes$class_object;

#endif	/* _JC_gnu_java_rmi_server_RMIHashes_H_ */

==> jc-1.4.6.tar.gz: gnu/java/rmi/server/RMIHashes.h <==
// public class gnu.java.rmi.server.RMIHashes

// class file dependencies
// @dep_class 857e3dcd87e13f83 gnu_java_rmi_server_RMIHashes
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_rmi_server_RMIHashes_H_
#define _JC_gnu_java_rmi_server_RMIHashes_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_reflect_Method$object;

// Typedefs
typedef struct _jc_gnu_java_rmi_server_RMIHashes$sub_refs	_jc_gnu_java_rmi_server_RMIHashes$sub_refs;
typedef struct _jc_gnu_java_rmi_server_RMIHashes$sub_nonrefs	_jc_gnu_java_rmi_server_RMIHashes$sub_nonrefs;
typedef struct _jc_gnu_java_rmi_server_RMIHashes$refs	_jc_gnu_java_rmi_server_RMIHashes$refs;
typedef struct _jc_gnu_java_rmi_server_RMIHashes$nonrefs	_jc_gnu_java_rmi_server_RMIHashes$nonrefs;
typedef struct _jc_gnu_java_rmi_server_RMIHashes$object	_jc_gnu_java_rmi_server_RMIHashes$object;

typedef const struct _jc_gnu_java_rmi_server_RMIHashes$vmethods	_jc_gnu_java_rmi_server_RMIHashes$vmethods;
typedef const struct _jc_gnu_java_rmi_server_RMIHashes$vtable	_jc_gnu_java_rmi_server_RMIHashes$vtable;
typedef const struct _jc_gnu_java_rmi_server_RMIHashes$vtype	_jc_gnu_java_rmi_server_RMIHashes$vtype;

// Constructors
extern void _jc_gnu_java_rmi_server_RMIHashes$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_rmi_server_RMIHashes$object *) _JC_JCNI_ATTR;

// Static methods
extern jlong _jc_gnu_java_rmi_server_RMIHashes$method$getInterfaceHash$f12cb538871a5af9(_jc_env *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;
extern jlong _jc_gnu_java_rmi_server_RMIHashes$method$getMethodHash$a47f54d288819e0e(_jc_env *, struct _jc_java_lang_reflect_Method$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_rmi_server_RMIHashes$vmethods {
};

// Vtable
struct _jc_gnu_java_rmi_server_RMIHashes$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_rmi_server_RMIHashes$vmethods	gnu_java_rmi_server_RMIHashes;
};

// Vtype
struct _jc_gnu_java_rmi_server_RMIHashes$vtype {
	_jc_type			type;
	_jc_gnu_java_rmi_server_RMIHashes$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_rmi_server_RMIHashes$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_rmi_server_RMIHashes$refs {
    _jc_gnu_java_rmi_server_RMIHashes$sub_refs	gnu_java_rmi_server_RMIHashes;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_rmi_server_RMIHashes$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_rmi_server_RMIHashes$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_rmi_server_RMIHashes$sub_nonrefs	gnu_java_rmi_server_RMIHashes;
};

// Object instance structure
struct _jc_gnu_java_rmi_server_RMIHashes$object {
	_jc_gnu_java_rmi_server_RMIHashes$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_rmi_server_RMIHashes$vtype	*vtype;
	_jc_gnu_java_rmi_server_RMIHashes$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_rmi_server_RMIHashes$vtype _jc_gnu_java_rmi_server_RMIHashes$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_rmi_server_RMIHashes, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_rmi_server_RMIHashes$class_object;

#endif	/* _JC_gnu_java_rmi_server_RMIHashes_H_ */
